@@ -17,6 +17,8 @@ from dataclasses_json import DataClassJsonMixin
 
 from annofabapi.models import GraphType, TaskPhase, TaskStatus
 
+warnings.warn("'annofabapi.dataclass.statistics'モジュールは2022-12-01以降に廃止する予定です。", FutureWarning, stacklevel=2)
+
 
 @dataclass
 class ProjectTaskStatistics(DataClassJsonMixin):
@@ -226,16 +228,16 @@ class WorktimeStatistics(DataClassJsonMixin):
 class Marker(DataClassJsonMixin):
     """ """
 
-    marker_id: Optional[str]
+    marker_id: str
     """マーカーID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
-    title: Optional[str]
+    title: str
     """マーカーのタイトル"""
 
-    graph_type: Optional[GraphType]
+    graph_type: GraphType
     """"""
 
-    marked_at: Optional[str]
+    marked_at: str
     """グラフ上のマーカー位置(x軸)"""
 
 
@@ -246,7 +248,7 @@ class Markers(DataClassJsonMixin):
     project_id: str
     """プロジェクトID。[値の制約についてはこちら。](#section/API-Convention/APIID) """
 
-    markers: Optional[List[Marker]]
+    markers: List[Marker]
     """マーカー一覧"""
 
     updated_datetime: Optional[str]
